package PDA::Pilot::Secret;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);

require Exporter;
require DynaLoader;
require AutoLoader;

@ISA = qw(Exporter AutoLoader DynaLoader);
# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.
@EXPORT = qw(
  &garble &crypt &decrypt &check_stdout
);
$VERSION = '0.01';

bootstrap PDA::Pilot::Secret $VERSION;

# Preloaded methods go here.

# Autoload methods go after =cut, and are processed by the autosplit program.

1;
__END__
# Below is the stub of documentation for your module. You better edit it!

=head1 NAME

PDA::Pilot::Secret - Perl extension to read a Secret2 database

=head1 SYNOPSIS

  use PDA::Pilot::Secret;
  $garbledpw = garble($passwd)
  $check_stdout()
  $crypted_string = crypt($string, $garbledpw, $length)
  $decrypted_string = decrypt($string, $garbledpw, $length)

=head1 DESCRIPTION

PDA::Pilot::Secret contains the three functions needed to decrypt a
Secret2 database. Secret2 is a program for the PalmPilot series of
PDAs that permits storing encrypted data. 

The Perl script decrypt.pl coming with this distribution illustrates
the usage of PDA::Pilot::Secret. It decrypts a Secret2 database passed on
the command line.

Since the database must be stored locally, an additional tool is
needed to download it from the PalmPilot. Such tools are pilot-link (included 
in most Linux distributions) or ColdSync (http://www.ooblick.com/software/coldsync/).

check_stdout is a utility function returning 1 if stdout is connected to a tty
and 0 otherwise. Since it's probably not a good idea to store the decrypted data
in a file, it should be called at the start of any program using PDA::Pilot::Secret, 
and the program should die with an appropriate message if it returns 0.

=head1 AUTHOR

Christian Kirsch

ck@ix.heise.de

=cut
